byte

Macro byte 

macro_rules! byte {
    ($ctx:expr, $value:expr, $($description:tt)*) => { ... };
}
Print the binary representation for the given byte, along with a formatted description at the current debug depth.

Example:

let value = 0b0010_1010;
debug::byte(value, "is binary for {}", value);

Prints:

00101010 is binary for 42